@@ -59,6 +59,7 @@
 #include "openswan/ipsec_xform.h"
 #include "openswan/ipsec_tunnel.h"
 #include "openswan/ipsec_rcv.h" /* sysctl_ipsec_inbound_policy_check */
+extern int sysctl_ipsec_inbound_policy_check;
 #include "openswan/ipsec_proto.h"
 #include "openswan/ipcomp.h"
 #include "zlib/zlib.h"
@@ -234,14 +235,12 @@ struct sk_buff *skb_compress(struct sk_buff *skb, struct ipsec_sa *ips, unsigned
 		return skb;
 	}
 	
-#ifdef CONFIG_KLIPS_DEBUG
 	if(sysctl_ipsec_debug_ipcomp && sysctl_ipsec_debug_verbose) {
 		__u8 *c;
 
 		c = (__u8*)iph + iphlen;
 		ipsec_dmp_block("compress before", c, pyldsz);
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 
 	zs.next_in = (char *) iph + iphlen; /* start of payload */
 	zs.avail_in = pyldsz;
@@ -316,14 +315,12 @@ struct sk_buff *skb_compress(struct sk_buff *skb, struct ipsec_sa *ips, unsigned
 	/* Update skb length/tail by "unputting" the shrinkage */
         safe_skb_put (skb, cpyldsz + sizeof(struct ipcomphdr) - pyldsz);
 
-#ifdef CONFIG_KLIPS_DEBUG
 	if(sysctl_ipsec_debug_ipcomp && sysctl_ipsec_debug_verbose) {
 		__u8 *c;
 		
 		c = (__u8*)iph + iphlen + sizeof(struct ipcomphdr);
 		ipsec_dmp_block("compress result", c, cpyldsz);
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 	
 	ips->ips_comp_adapt_skip = 0;
 	ips->ips_comp_adapt_tries = 0;
@@ -478,14 +475,12 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 		return skb;
 	}
 	
-#ifdef CONFIG_KLIPS_DEBUG
 	if(sysctl_ipsec_debug_ipcomp && sysctl_ipsec_debug_verbose) {
 		__u8 *c;
 		
 		c = (__u8*)oiph + iphlen + sizeof(struct ipcomphdr);
 		ipsec_dmp_block("decompress before", c, cpyldsz);
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 
 #ifdef NET_21
 	iph = ip_hdr(nskb);
@@ -549,25 +544,21 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 	
 	if (iph->protocol == IPPROTO_COMP)
 	{
-#ifdef CONFIG_KLIPS_DEBUG
 		if(sysctl_ipsec_debug_ipcomp)
 		KLIPS_PRINT(sysctl_ipsec_debug_ipcomp,
 			    "klips_debug:skb_decompress: "
 			    "Eh? inner packet is also compressed, dropping.\n");
-#endif /* CONFIG_KLIPS_DEBUG */
 		
 		ipsec_kfree_skb(nskb);
 		return NULL;
 	}
 	
-#ifdef CONFIG_KLIPS_DEBUG
 	if(sysctl_ipsec_debug_ipcomp && sysctl_ipsec_debug_verbose) {
 		__u8 *c;
 		
 		c = (__u8*)iph + iphlen;
 		ipsec_dmp_block("decompress result", c, pyldsz);
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 	
 	return nskb;
 }
