@@ -163,7 +163,6 @@ ipsec_tunnel_strip_hard_header(struct ipsec_xmit_state *ixs)
 		ixs->hard_header_len = ixs->physdev->hard_header_len;
 	}
 
-#ifdef CONFIG_KLIPS_DEBUG
 	if (debug_tunnel & DB_TN_XMIT) {
 		int i;
 		char c;
@@ -178,7 +177,6 @@ ipsec_tunnel_strip_hard_header(struct ipsec_xmit_state *ixs)
 		}
 		printk(" \n");
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 
 	KLIPS_IP_PRINT(debug_tunnel & DB_TN_XMIT, ixs->iph);
 
@@ -418,7 +416,7 @@ ipsec_tunnel_SAlookup(struct ipsec_xmit_state *ixs)
 				    "klips_debug:ipsec_xmit_SAlookup: "
 				    "shunt SA of HOLD: skb stored in HOLD.\n");
 			if(ixs->eroute->er_last != NULL) {
-				kfree_skb(ixs->eroute->er_last);
+				ipsec_kfree_skb(ixs->eroute->er_last);
 			}
 			ixs->eroute->er_last = ixs->skb;
 			ixs->skb = NULL;
@@ -610,6 +608,11 @@ ipsec_tunnel_start_xmit(struct sk_buff *skb, struct net_device *dev)
 	stat = IPSEC_XMIT_ERRMEMALLOC;
 	ixs = ipsec_xmit_state_new();
 	if (! ixs) {
+		struct ipsecpriv *prv;
+		struct net_device_stats *stats;
+		prv = dev->priv;
+		stats = (struct net_device_stats *) &(prv->mystats);
+		stats->tx_dropped++;
 		goto alloc_error;
 	}
 
@@ -649,7 +652,9 @@ ipsec_tunnel_start_xmit(struct sk_buff *skb, struct net_device *dev)
  cleanup:
 	ipsec_xmit_cleanup(ixs);
 	ipsec_xmit_state_delete(ixs);
+	return 0;
 alloc_error:
+	ipsec_kfree_skb(skb);
 	return 0;
 }
 
@@ -1172,7 +1177,6 @@ ipsec_tunnel_attach(struct net_device *dev, struct net_device *physdev)
 	for (i=0; i<dev->addr_len; i++) {
 		dev->dev_addr[i] = physdev->dev_addr[i];
 	}
-#ifdef CONFIG_KLIPS_DEBUG
 	if(debug_tunnel & DB_TN_INIT) {
 		printk(KERN_INFO "klips_debug:ipsec_tunnel_attach: "
 		       "physical device %s being attached has HW address: %2x",
@@ -1182,7 +1186,6 @@ ipsec_tunnel_attach(struct net_device *dev, struct net_device *physdev)
 		}
 		printk("\n");
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 
 	return 0;
 }
