@@ -133,12 +133,7 @@ static __u32 zeroes[64];
 int ipsec_xmit_trap_count = 0;
 int ipsec_xmit_trap_sendcount = 0;
 
-#ifdef CONFIG_KLIPS_DEBUG
 #define dmp(_x,_y,_z) if(debug_xmit && sysctl_ipsec_debug_verbose) ipsec_dmp_block(_x,_y,_z)
-#else /* CONFIG_KLIPS_DEBUG */
-#define dmp(_x, _y, _z) 
-#endif /* CONFIG_KLIPS_DEBUG */
-
 
 #if !defined(SKB_COPY_EXPAND) || defined(KLIPS_UNIT_TESTS)
 /*
@@ -262,7 +257,6 @@ skb_copy_expand(const struct sk_buff *skb, int headroom,
 }
 #endif /* !SKB_COPY_EXPAND */
 
-#ifdef CONFIG_KLIPS_DEBUG
 void
 ipsec_print_ip(struct iphdr *ip)
 {
@@ -324,7 +318,6 @@ ipsec_print_ip(struct iphdr *ip)
 		ipsec_dmp_block("ip_print", c, len);
 	}
 }
-#endif /* CONFIG_KLIPS_DEBUG */
 
 #ifdef MSS_HACK
 /*
@@ -376,7 +369,6 @@ ipsec_adjust_mss(struct sk_buff *skb, struct tcphdr *tcph, u_int16_t mtu)
 }
 #endif	/* MSS_HACK */
 
-#ifdef CONFIG_KLIPS_DEBUG
 DEBUG_NO_STATIC char *
 ipsec_xmit_err(int err)
 {
@@ -418,7 +410,6 @@ ipsec_xmit_err(int err)
 	snprintf(tmp, sizeof(tmp), "%d", err);
 	return tmp;
 }
-#endif
                                                         
 /*
  * Sanity checks
@@ -765,11 +756,9 @@ ipsec_xmit_esp(struct ipsec_xmit_state *ixs)
 		return IPSEC_XMIT_ESP_BADALG;
 	}
 	
-#ifdef CONFIG_KLIPS_DEBUG		
 	if(debug_tunnel & DB_TN_ENCAP) {
 		dmp("pre-encrypt", ixs->dat, ixs->len);
 	}
-#endif
 
 	/*
 	 * Do all operations here:
@@ -1028,14 +1017,10 @@ ipsec_xmit_ipip(struct ipsec_xmit_state *ixs)
 enum ipsec_xmit_value
 ipsec_xmit_ipcomp(struct ipsec_xmit_state *ixs)
 {
-#ifdef CONFIG_KLIPS_DEBUG
 	unsigned int old_tot_len;
-#endif
 	int flags = 0;
 
-#ifdef CONFIG_KLIPS_DEBUG
 	old_tot_len = ntohs(ixs->iph->tot_len);
-#endif /* CONFIG_KLIPS_DEBUG */
 
 	ixs->ipsp->ips_comp_ratio_dbytes += ntohs(ixs->iph->tot_len);
 	ixs->skb = skb_compress(ixs->skb, ixs->ipsp, &flags);
@@ -1048,7 +1033,6 @@ ipsec_xmit_ipcomp(struct ipsec_xmit_state *ixs)
 
 	ixs->ipsp->ips_comp_ratio_cbytes += ntohs(ixs->iph->tot_len);
 
-#ifdef CONFIG_KLIPS_DEBUG
 	if (debug_tunnel & DB_TN_CROUT)
 	{
 		if (old_tot_len > ntohs(ixs->iph->tot_len))
@@ -1065,7 +1049,6 @@ ipsec_xmit_ipcomp(struct ipsec_xmit_state *ixs)
 					"packet did not compress (flags = %d).\n",
 					flags);
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 	return IPSEC_XMIT_OK;
 }
 
@@ -1109,7 +1092,13 @@ ipsec_xmit_cont(struct ipsec_xmit_state *ixs)
 	ixs->ipsp->ips_life.ipl_usetime.ipl_last = jiffies / HZ;
 	ixs->ipsp->ips_life.ipl_packets.ipl_count++; 
 
+	/* we are done with this SA */
+	ipsec_sa_put(ixs->ipsp); 
+
+	/* move to the next SA */
 	ixs->ipsp = ixs->ipsp->ips_next;
+	if (ixs->ipsp)
+		ipsec_sa_get(ixs->ipsp);
 
 	/*
 	 * start again if we have more work to do
@@ -1207,7 +1196,6 @@ static int create_hold_eroute(struct eroute *origtrap,
 	  }
 	}
 
-#ifdef CONFIG_KLIPS_DEBUG
 	if (debug_pfkey) {
 		char buf1[64], buf2[64];
 		subnettoa(hold_eroute.er_eaddr.sen_ip_src,
@@ -1221,7 +1209,6 @@ static int create_hold_eroute(struct eroute *origtrap,
 			    buf2, ntohs(hold_eroute.er_eaddr.sen_dport),
 			    hold_eroute.er_eaddr.sen_proto);
 	}
-#endif /* CONFIG_KLIPS_DEBUG */
 
 	if (ipsec_breakroute(&(hold_eroute.er_eaddr), &(hold_eroute.er_emask),
 			     &first, &last)) {
@@ -1239,9 +1226,9 @@ static int create_hold_eroute(struct eroute *origtrap,
 			    hold_eroute.er_eaddr.sen_proto);
 	}
 	if (first != NULL)
-		kfree_skb(first);
+		ipsec_kfree_skb(first);
 	if (last != NULL)
-		kfree_skb(last);
+		ipsec_kfree_skb(last);
 
 	error = ipsec_makeroute(&(hold_eroute.er_eaddr),
 				&(hold_eroute.er_emask),
@@ -1318,9 +1305,7 @@ ipsec_xmit_init1(struct ipsec_xmit_state *ixs)
 		case SPI_TRAPSUBNET:
 		{
 			struct sockaddr_in src, dst;
-#ifdef CONFIG_KLIPS_DEBUG
 			char bufsrc[ADDRTOA_BUF], bufdst[ADDRTOA_BUF];
-#endif /* CONFIG_KLIPS_DEBUG */
 
 			/* Signal all listening KMds with a PF_KEY ACQUIRE */
 
@@ -1888,11 +1873,9 @@ ipsec_xmit_init2(struct ipsec_xmit_state *ixs)
 			    skb_headroom(ixs->skb), skb_tailroom(ixs->skb));
 	}
 		
-#ifdef CONFIG_KLIPS_DEBUG
 	if(debug_tunnel & DB_TN_ENCAP) {
 		ipsec_print_ip(ixs->iph);
 	}
-#endif
 
 cleanup:
 	return bundle_stat;
@@ -1914,11 +1897,11 @@ ipsec_xmit_cleanup(struct ipsec_xmit_state*ixs)
 		ixs->saved_header = NULL;
 	}
 	if(ixs->skb) {
-		dev_kfree_skb(ixs->skb);
+		ipsec_kfree_skb(ixs->skb);
 		ixs->skb=NULL;
 	}
 	if(ixs->oskb) {
-		dev_kfree_skb(ixs->oskb);
+		ipsec_kfree_skb(ixs->oskb);
 		ixs->oskb=NULL;
 	}
 	if (ixs->ips.ips_ident_s.data) {
@@ -1929,6 +1912,10 @@ ipsec_xmit_cleanup(struct ipsec_xmit_state*ixs)
 		kfree(ixs->ips.ips_ident_d.data);
 		ixs->ips.ips_ident_d.data=NULL;
 	}
+	if(ixs->ipsp) {
+			ipsec_sa_put(ixs->ipsp);
+			ixs->ipsp=NULL;
+	}
 }
 
 #ifdef NETDEV_23
@@ -2029,14 +2016,13 @@ ipsec_xmit_send(struct ipsec_xmit_state*ixs, struct flowi *fl)
 				    ixs->pass ? 0 : ip_hdr(ixs->skb)->saddr,
 				    RT_TOS(ip_hdr(ixs->skb)->tos),
                                     /* mcr->rgb: should this be 0 instead? */
-				    ixs->physdev->iflink))) {
+				    ixs->physdev->ifindex))) {
 #endif
 		ixs->stats->tx_errors++;
 		KLIPS_PRINT(debug_tunnel & DB_TN_XMIT,
 			    "klips_debug:ipsec_xmit_send: "
-			    "ip_route_output failed with error code %d, rt->u.dst.dev=%s, dropped\n",
-			    error,
-			    ixs->route->u.dst.dev->name);
+			    "ip_route_output failed with error code %d, dropped\n",
+			    error);
 		return IPSEC_XMIT_ROUTEERR;
 	}
 
@@ -2082,9 +2068,12 @@ ipsec_xmit_send(struct ipsec_xmit_state*ixs, struct flowi *fl)
 	{
 		int err;
 
-/* XXX huh, we include linux/netfilter_ipv4.h where NF_IP_LOCAL_OUT is defined as 3 */
+/*
+ * XXX: We include linux/netfilter_ipv4.h where NF_IP_LOCAL_OUT is defined as 3,
+ * but an ifndef __KERNEL__ prevents us from using it. There must be a reason? 
+ */
 #ifndef NF_IP_LOCAL_OUT
-#warning I dont understand why NF_IP_LOCAL_OUT is undefined when including linux/netfilter_ipv4.h
+#warning NF_IP_LOCAL_OUT hardcoded to 3 - from linux/netfilter_ipv4.h which does not allow including in kernel mode
 #define NF_IP_LOCAL_OUT 3
 #endif
 		err = NF_HOOK(PF_INET, NF_IP_LOCAL_OUT, ixs->skb, NULL,
@@ -2125,7 +2114,7 @@ ipsec_tunnel_send(struct ipsec_xmit_state *ixs)
 
 	/* new route/dst cache code from James Morris */
 	ixs->skb->dev = ixs->physdev;
- 	fl.oif = ixs->physdev->iflink;
+ 	fl.oif = ixs->physdev->ifindex;
 
 	return ipsec_xmit_send(ixs, &fl);
 }
@@ -2205,17 +2194,25 @@ ipsec_xsm(struct ipsec_xmit_state *ixs)
 	 * hasn't gone away while we were waiting for a task to complete
 	 */
 
-	if (ixs->ipsp && ipsec_sa_getbyid(&ixs->outgoing_said) == NULL) {
-		KLIPS_PRINT(debug_tunnel,
-			    "klips_debug:ipsec_xsm: "
-			    "no ipsec_sa for SA:%s: outgoing packet with no SA dropped\n",
-			    ixs->sa_len ? ixs->sa_txt : " (error)");
-		if (ixs->stats)
-			ixs->stats->tx_dropped++;
+	if (ixs->ipsp) {
+		struct ipsec_sa *ipsp;
+		ipsp = ipsec_sa_getbyid(&ixs->outgoing_said);
+		if (unlikely(ipsp == NULL)) {
+			KLIPS_PRINT(debug_tunnel,
+				"klips_debug:ipsec_xsm: "
+				"no ipsec_sa for SA:%s: "
+				"outgoing packet with no SA dropped\n",
+				ixs->sa_len ? ixs->sa_txt : " (error)");
+			if (ixs->stats)
+				ixs->stats->tx_dropped++;
 
-		/* drop through and cleanup */
-		stat = IPSEC_XMIT_SAIDNOTFOUND;
-		ixs->state = IPSEC_XSM_DONE;
+			/* drop through and cleanup */
+			stat = IPSEC_XMIT_SAIDNOTFOUND;
+			ixs->state = IPSEC_XSM_DONE;
+		} else {
+			/* put the ref count back */
+			ipsec_sa_put(ipsp);
+		}
 	}
 
 	while (ixs->state != IPSEC_XSM_DONE) {
@@ -2249,12 +2246,6 @@ ipsec_xsm(struct ipsec_xmit_state *ixs)
 	 */
 	spin_unlock_bh(&tdb_lock);
 
-	/* we are done with this SA */
-	if (ixs->ipsp) {
-		ipsec_sa_put(ixs->ipsp); 
-		ixs->ipsp = NULL;
-	}
-
 	/*
 	 * let the caller continue with their processing
 	 */
