@@ -247,6 +247,15 @@ delete_connection(struct connection *c, bool relations)
 #ifdef DEBUG
     lset_t old_cur_debugging = cur_debugging;
 #endif
+	union {
+		struct alg_info**     ppai;
+#ifdef KERNEL_ALG
+		struct alg_info_esp** ppai_esp;
+#endif
+#ifdef IKE_ALG
+		struct alg_info_ike** ppai_ike;
+#endif
+	} palg_info;
 
     set_cur_connection(c);
 
@@ -323,10 +332,12 @@ delete_connection(struct connection *c, bool relations)
 
     gw_delref(&c->gw_info);
 #ifdef KERNEL_ALG
-    alg_info_delref((struct alg_info **)&c->alg_info_esp);
+    palg_info.ppai_esp = &c->alg_info_esp;
+    alg_info_delref(palg_info.ppai);
 #endif
 #ifdef IKE_ALG
-    alg_info_delref((struct alg_info **)&c->alg_info_ike);
+    palg_info.ppai_ike = &c->alg_info_ike;
+    alg_info_delref(palg_info.ppai);
 #endif
     pfree(c);
 }
@@ -2194,7 +2205,6 @@ find_host_connection2(const char *func
     return c;
 }
 
-#if 0
 /*
  * extracts the peer's ca from the chained list of public keys
  */
@@ -2214,7 +2224,6 @@ get_peer_ca(const struct id *peer_id)
     }
     return empty_chunk;
 }
-#endif
 
 
 
@@ -2296,8 +2305,6 @@ refine_host_connection(const struct state *st, const struct id *peer_id
 
     psk = NULL;
 
-    zero(&peer_ca);
-
     our_pathlen = peer_pathlen = 0;
     best_our_pathlen  = 0;
     best_peer_pathlen = 0;
@@ -2305,18 +2312,14 @@ refine_host_connection(const struct state *st, const struct id *peer_id
 
     /* zero it, so because we will test it later, to see if we found
      * something, and the get_peer_ca code is uncertain. */
-    memset(&peer_ca, 0, sizeof(peer_ca));
+    zero(&peer_ca);
 
     DBG(DBG_CONTROLMORE
 	 , DBG_log("refine_connection: starting with %s"
 		   , c->name));
 
-#if 0
     peer_ca = get_peer_ca(peer_id);
 
-    /* XXX I think that this code should be done later on, or maybe not
-     * at all, since we should conclude the same thing below.
-     */
     if (same_id(&c->spd.that.id, peer_id)
 	&& (peer_ca.ptr != NULL)
 	&& trusted_ca(peer_ca, c->spd.that.ca, &peer_pathlen)
@@ -2331,7 +2334,6 @@ refine_host_connection(const struct state *st, const struct id *peer_id
 
 	return c;	/* peer ID matches current connection -- look no further */
     }
-#endif
 
 #if defined(XAUTH)
     auth = xauth_calcbaseauth(auth);
@@ -2791,8 +2793,8 @@ fc_try_oppo(const struct connection *c
 	    continue;
 
 	if (!(same_id(&c->spd.this.id, &d->spd.this.id)
-	&& match_id(&c->spd.that.id, &d->spd.that.id, &wildcards)
-	&& trusted_ca(c->spd.that.ca, d->spd.that.ca, &pathlen)))
+	      && match_id(&c->spd.that.id, &d->spd.that.id, &wildcards)
+	      && trusted_ca(c->spd.that.ca, d->spd.that.ca, &pathlen)))
 	    continue;
 
 	/* compare protocol and ports */
@@ -3037,11 +3039,225 @@ connection_compare_qsort(const void *a, const void *b)
 			    , *(const struct connection *const *)b);
 }
 
+static void
+show_one_sr(struct connection *c
+	    , struct spd_route *sr
+	    , int num UNUSED
+	    , char *instance)
+{
+    char topo[CONN_BUF_LEN];
+    char srcip[ADDRTOT_BUF], dstip[ADDRTOT_BUF];
+    char thissemi[3+sizeof("myup=")];
+    char thatsemi[3+sizeof("hisup=")];
+#ifdef XAUTH
+    char thisxauthsemi[XAUTH_USERNAME_LEN+sizeof("myxauthuser=")];
+    char thatxauthsemi[XAUTH_USERNAME_LEN+sizeof("hisxauthuser=")];
+#endif
+    char thiscertsemi[3+sizeof("mycert=")+PATH_MAX];
+    char thatcertsemi[3+sizeof("hiscert=")+PATH_MAX];
+    char *thisup, *thatup;
+    
+    (void) format_connection(topo, sizeof(topo), c, sr);
+    whack_log(RC_COMMENT, "\"%s\"%s: %s; %s; eroute owner: #%lu"
+	      , c->name, instance, topo
+	      , enum_name(&routing_story, sr->routing)
+	      , sr->eroute_owner);
+    if(addrbytesptr(&c->spd.this.host_srcip, NULL) == 0
+       || isanyaddr(&c->spd.this.host_srcip)) {
+	strcpy(srcip, "unset");
+    } else {
+	addrtot(&sr->this.host_srcip, 0, srcip, sizeof(srcip));
+    }
+    if(addrbytesptr(&c->spd.that.host_srcip, NULL) == 0
+       || isanyaddr(&c->spd.that.host_srcip)) {
+	strcpy(dstip, "unset");
+    } else {
+	addrtot(&sr->that.host_srcip, 0, dstip, sizeof(dstip));
+    }
+    
+    thissemi[0]='\0';
+    thisup=thissemi;
+    if(sr->this.updown) {
+	thissemi[0]=';';
+	thissemi[1]=' ';
+	thissemi[2]='\0';
+	strcat(thissemi, "myup=");
+	thisup=sr->this.updown;
+    }
+    
+    thatsemi[0]='\0';
+    thatup=thatsemi;
+    if(sr->that.updown) {
+	thatsemi[0]=';';
+	thatsemi[1]=' ';
+	thatsemi[2]='\0';
+	strcat(thatsemi, "hisup=");
+	thatup=sr->that.updown;
+    }
+    
+    thiscertsemi[0]='\0';
+    if(sr->this.cert_filename) {
+	snprintf(thiscertsemi, sizeof(thiscertsemi)-1
+		 , "; mycert=%s"
+		 , sr->this.cert_filename);
+    }
+    
+    thatcertsemi[0]='\0';
+    if(sr->that.cert_filename) {
+	snprintf(thatcertsemi, sizeof(thatcertsemi)-1
+		 , "; hiscert=%s"
+		 , sr->that.cert_filename);
+    }
+
+    whack_log(RC_COMMENT, "\"%s\"%s:     myip=%s; hisip=%s%s%s%s%s%s%s;"
+	      , c->name, instance, srcip, dstip
+	      , thissemi, thisup
+	      , thatsemi, thatup
+	      , thiscertsemi
+	      , thatcertsemi);
+    
+#ifdef XAUTH
+    if(sr->this.xauth_name || sr->that.xauth_name) {
+	thisxauthsemi[0]='\0';
+	if(sr->this.xauth_name) {
+	    snprintf(thisxauthsemi, sizeof(thisxauthsemi)-1
+		     , "myxauthuser=%s; "
+		     , sr->this.xauth_name);
+	}
+	
+	thatxauthsemi[0]='\0';
+	if(sr->that.xauth_name) {
+	    snprintf(thatxauthsemi, sizeof(thatxauthsemi)-1
+		     , "hisxauthuser=%s; "
+		     , sr->that.xauth_name);
+	}
+	whack_log(RC_COMMENT, "\"%s\"%s:     xauth info: %s%s"
+		  , c->name, instance
+		  , thisxauthsemi
+		  , thatxauthsemi);
+    }
+#endif
+}
+
+void 
+show_one_connection(struct connection *c)
+{
+    const char *ifn;
+    char instance[1 + 10 + 1];
+    char prio[POLICY_PRIO_BUF];
+    
+    ifn = oriented(*c)? c->interface->ip_dev->id_rname : "";
+
+    instance[0] = '\0';
+    if (c->kind == CK_INSTANCE && c->instance_serial != 0)
+	snprintf(instance, sizeof(instance), "[%lu]", c->instance_serial);
+    
+    /* show topology */
+    {
+	struct spd_route *sr = &c->spd;
+	int num=0;
+	
+	while (sr != NULL)
+	{
+	    show_one_sr(c, sr, num, instance);
+	    sr = sr->next;
+	    num++;
+	}
+    }
+    
+    /* show CAs */
+    if (c->spd.this.ca.ptr != NULL || c->spd.that.ca.ptr != NULL)
+    {
+	char this_ca[IDTOA_BUF], that_ca[IDTOA_BUF];
+	
+	dntoa_or_null(this_ca, IDTOA_BUF, c->spd.this.ca, "%any");
+	dntoa_or_null(that_ca, IDTOA_BUF, c->spd.that.ca, "%any");
+	
+	whack_log(RC_COMMENT
+		  , "\"%s\"%s:   CAs: '%s'...'%s'"
+		  , c->name
+		  , instance
+		  , this_ca
+		  , that_ca);
+    }
+    
+    whack_log(RC_COMMENT
+	      , "\"%s\"%s:   ike_life: %lus; ipsec_life: %lus;"
+	      " rekey_margin: %lus; rekey_fuzz: %lu%%; keyingtries: %lu"
+	      , c->name
+	      , instance
+	      , (unsigned long) c->sa_ike_life_seconds
+	      , (unsigned long) c->sa_ipsec_life_seconds
+	      , (unsigned long) c->sa_rekey_margin
+	      , (unsigned long) c->sa_rekey_fuzz
+	      , (unsigned long) c->sa_keying_tries);
+
+    if (c->policy_next)
+    {
+	whack_log(RC_COMMENT
+		  , "\"%s\"%s:   policy_next: %s"
+		  , c->name, instance, c->policy_next->name);
+    }
+    
+    /* Note: we display key_from_DNS_on_demand as if policy [lr]KOD */
+    fmt_policy_prio(c->prio, prio);
+    whack_log(RC_COMMENT
+	      , "\"%s\"%s:   policy: %s%s%s; prio: %s; interface: %s; "
+	      , c->name
+	      , instance
+	      , prettypolicy(c->policy)
+	      , c->spd.this.key_from_DNS_on_demand? "+lKOD" : ""
+	      , c->spd.that.key_from_DNS_on_demand? "+rKOD" : ""
+	      , prio
+	      , ifn);
+    
+    /* slightly complicated stuff to avoid extra crap */
+    if(c->dpd_timeout > 0 || DBGP(DBG_DPD)) {
+	whack_log(RC_COMMENT
+		  , "\"%s\"%s:   dpd: %s; delay:%lu; timeout:%lu; "
+		  , c->name
+		  , instance
+		  , enum_name(&dpd_action_names, c->dpd_action)
+		  , (unsigned long)c->dpd_delay
+		  , (unsigned long)c->dpd_timeout);
+    }
+
+    if(c->extra_debugging) {
+	whack_log(RC_COMMENT, "\"%s\"%s:   debug: %s"
+		  , c->name
+		  , instance
+		  , bitnamesof(debug_bit_names
+			       , c->extra_debugging));
+    }
+    
+    whack_log(RC_COMMENT
+	      , "\"%s\"%s:   newest ISAKMP SA: #%ld; newest IPsec SA: #%ld; "
+	      , c->name
+	      , instance
+	      , c->newest_isakmp_sa
+	      , c->newest_ipsec_sa);
+    
+    if(c->connalias) {
+	whack_log(RC_COMMENT
+		  , "\"%s\"%s:   aliases: %s\n"
+		  , c->name
+		  , instance
+		  , c->connalias);
+    }
+    
+#ifdef IKE_ALG
+    ike_alg_show_connection(c, instance);
+#endif
+#ifdef KERNEL_ALG
+    kernel_alg_show_connection(c, instance);
+#endif
+}
+
 void
 show_connections_status(void)
 {
-    struct connection *c;
     int count, i;
+    struct connection *c;
     struct connection **array;
 
 
@@ -3068,208 +3284,7 @@ show_connections_status(void)
 
     for (i=0; i<count; i++)
     {
-	const char *ifn;
-	char instance[1 + 10 + 1];
-	char prio[POLICY_PRIO_BUF];
-
-	c = array[i];
-
-	ifn = oriented(*c)? c->interface->ip_dev->id_rname : "";
-
-	instance[0] = '\0';
-	if (c->kind == CK_INSTANCE && c->instance_serial != 0)
-	    snprintf(instance, sizeof(instance), "[%lu]", c->instance_serial);
-
-	/* show topology */
-	{
-	    char topo[CONN_BUF_LEN];
-	    struct spd_route *sr = &c->spd;
-	    int num=0;
-
-	    while (sr != NULL)
-	    {
-		char srcip[ADDRTOT_BUF], dstip[ADDRTOT_BUF];
-		char thissemi[3+sizeof("myup=")];
-		char thatsemi[3+sizeof("hisup=")];
-#ifdef XAUTH
-		char thisxauthsemi[XAUTH_USERNAME_LEN+sizeof("myxauthuser=")];
-		char thatxauthsemi[XAUTH_USERNAME_LEN+sizeof("hisxauthuser=")];
-#endif
-		char thiscertsemi[3+sizeof("mycert=")+PATH_MAX];
-		char thatcertsemi[3+sizeof("hiscert=")+PATH_MAX];
-		char *thisup, *thatup;
-
-		(void) format_connection(topo, sizeof(topo), c, sr);
-		whack_log(RC_COMMENT, "\"%s\"%s: %s; %s; eroute owner: #%lu"
-			  , c->name, instance, topo
-			  , enum_name(&routing_story, sr->routing)
-			  , sr->eroute_owner);
-		if(addrbytesptr(&c->spd.this.host_srcip, NULL) == 0
-		   || isanyaddr(&c->spd.this.host_srcip)) {
-		    strcpy(srcip, "unset");
-		} else {
-		    addrtot(&sr->this.host_srcip, 0, srcip, sizeof(srcip));
-		}
-		if(addrbytesptr(&c->spd.that.host_srcip, NULL) == 0
-		   || isanyaddr(&c->spd.that.host_srcip)) {
-		    strcpy(dstip, "unset");
-		} else {
-		    addrtot(&sr->that.host_srcip, 0, dstip, sizeof(dstip));
-		}
-
-		thissemi[0]='\0';
-		thisup=thissemi;
-		if(sr->this.updown) {
-		    thissemi[0]=';';
-		    thissemi[1]=' ';
-		    thissemi[2]='\0';
-		    strcat(thissemi, "myup=");
-		    thisup=sr->this.updown;
-		}
-		
-		thatsemi[0]='\0';
-		thatup=thatsemi;
-		if(sr->that.updown) {
-		    thatsemi[0]=';';
-		    thatsemi[1]=' ';
-		    thatsemi[2]='\0';
-		    strcat(thatsemi, "hisup=");
-		    thatup=sr->that.updown;
-		}
-		
-		thiscertsemi[0]='\0';
-		if(sr->this.cert_filename) {
-		    snprintf(thiscertsemi, sizeof(thiscertsemi)-1
-			     , "; mycert=%s"
-			     , sr->this.cert_filename);
-		}
-
-		thatcertsemi[0]='\0';
-		if(sr->that.cert_filename) {
-		    snprintf(thatcertsemi, sizeof(thatcertsemi)-1
-			     , "; hiscert=%s"
-			     , sr->that.cert_filename);
-		}
-
-		whack_log(RC_COMMENT, "\"%s\"%s:     myip=%s; hisip=%s%s%s%s%s%s%s;"
-			  , c->name, instance, srcip, dstip
-			  , thissemi, thisup
-			  , thatsemi, thatup
-			  , thiscertsemi
-			  , thatcertsemi);
-
-#ifdef XAUTH
-		if(sr->this.xauth_name || sr->that.xauth_name) {
-		    thisxauthsemi[0]='\0';
-		    if(sr->this.xauth_name) {
-			snprintf(thisxauthsemi, sizeof(thisxauthsemi)-1
-				 , "myxauthuser=%s; "
-				 , sr->this.xauth_name);
-		    }
-		    
-		    thatxauthsemi[0]='\0';
-		    if(sr->that.xauth_name) {
-			snprintf(thatxauthsemi, sizeof(thatxauthsemi)-1
-				 , "hisxauthuser=%s; "
-				 , sr->that.xauth_name);
-		    }
-		    whack_log(RC_COMMENT, "\"%s\"%s:     xauth info: %s%s"
-			      , c->name, instance
-			      , thisxauthsemi
-			      , thatxauthsemi);
-		}
-#endif
-		sr = sr->next;
-		num++;
-	    }
-	}
-
-	/* show CAs */
-	if (c->spd.this.ca.ptr != NULL || c->spd.that.ca.ptr != NULL)
-	{
-	    char this_ca[IDTOA_BUF], that_ca[IDTOA_BUF];
-
-	    dntoa_or_null(this_ca, IDTOA_BUF, c->spd.this.ca, "%any");
-	    dntoa_or_null(that_ca, IDTOA_BUF, c->spd.that.ca, "%any");
-
-	    whack_log(RC_COMMENT
-		, "\"%s\"%s:   CAs: '%s'...'%s'"
-		, c->name
-		, instance
-		, this_ca
-		, that_ca);
-	}
-
-	whack_log(RC_COMMENT
-	    , "\"%s\"%s:   ike_life: %lus; ipsec_life: %lus;"
-	    " rekey_margin: %lus; rekey_fuzz: %lu%%; keyingtries: %lu"
-	    , c->name
-	    , instance
-	    , (unsigned long) c->sa_ike_life_seconds
-	    , (unsigned long) c->sa_ipsec_life_seconds
-	    , (unsigned long) c->sa_rekey_margin
-	    , (unsigned long) c->sa_rekey_fuzz
-	    , (unsigned long) c->sa_keying_tries);
-
-	if (c->policy_next)
-	{
-	    whack_log(RC_COMMENT
-		      , "\"%s\"%s:   policy_next: %s"
-		      , c->name, instance, c->policy_next->name);
-	}
-
-	/* Note: we display key_from_DNS_on_demand as if policy [lr]KOD */
-	fmt_policy_prio(c->prio, prio);
-	whack_log(RC_COMMENT
-	    , "\"%s\"%s:   policy: %s%s%s; prio: %s; interface: %s; "
-	    , c->name
-	    , instance
-	    , prettypolicy(c->policy)
-	    , c->spd.this.key_from_DNS_on_demand? "+lKOD" : ""
-	    , c->spd.that.key_from_DNS_on_demand? "+rKOD" : ""
-	    , prio
-	    , ifn);
-
-	/* slightly complicated stuff to avoid extra crap */
-	if(c->dpd_timeout > 0 || DBGP(DBG_DPD)) {
-	    whack_log(RC_COMMENT
-		      , "\"%s\"%s:   dpd: %s; delay:%lu; timeout:%lu; "
-		      , c->name
-		      , instance
-		      , enum_name(&dpd_action_names, c->dpd_action)
-		      , (unsigned long)c->dpd_delay
-		      , (unsigned long)c->dpd_timeout);
-	}
-
-	if(c->extra_debugging) {
-	    whack_log(RC_COMMENT, "\"%s\"%s:   debug: %s"
-		      , c->name
-		      , instance
-		      , bitnamesof(debug_bit_names
-				   , c->extra_debugging));
-	}
-
-	whack_log(RC_COMMENT
-	    , "\"%s\"%s:   newest ISAKMP SA: #%ld; newest IPsec SA: #%ld; "
-	    , c->name
-	    , instance
-	    , c->newest_isakmp_sa
-	    , c->newest_ipsec_sa);
-
-	if(c->connalias) {
-	    whack_log(RC_COMMENT
-		      , "\"%s\"%s:   aliases: %s\n"
-		      , c->name
-		      , instance
-		      , c->connalias);
-	}
-
-#ifdef IKE_ALG
-	ike_alg_show_connection(c, instance);
-#endif
-#ifdef KERNEL_ALG
-	kernel_alg_show_connection(c, instance);
-#endif
+	show_one_connection(array[i]);
     }
     pfree(array);
 }
