@@ -538,7 +538,9 @@ dpd_timeout(struct state *st)
     /* probably wrong thing to assert here */
     passert(action == DPD_ACTION_HOLD
 	    || action == DPD_ACTION_CLEAR
-	    || action == DPD_ACTION_RESTART);
+	    || action == DPD_ACTION_RESTART
+	    || action == DPD_ACTION_RESTART_BY_PEER
+	    );
         
     /** delete the state, which is probably in phase 2 */
     set_cur_connection(c);
@@ -588,6 +590,12 @@ dpd_timeout(struct state *st)
 	delete_dpd_event(st);
 	event_schedule(EVENT_SA_REPLACE, 0, st);
 
+	case DPD_ACTION_RESTART_BY_PEER:
+	/* dpdaction=restart_by_peer - immediately renegotiate connections to the same peer. */
+	openswan_log("DPD: Restarting all connections that share this peer");
+	restart_connections_by_peer(c);
+	break;
+
 	break;
     }
     reset_cur_connection();
