@@ -664,9 +664,25 @@ encrypt_message(pb_stream *pbs, struct state *st)
 /* Handle a Main Mode Oakley first packet (responder side).
  * HDR;SA --> HDR;SA
  */
+
+#ifdef DMALLOC
+static unsigned long _dm_mark = 0;
+static unsigned long _dm_initialized = 0;
+#endif
+
 stf_status
 main_inI1_outR1(struct msg_digest *md)
 {
+#ifdef DMALLOC
+     if (_dm_initialized != 0) {
+	/* log unfreed pointers that have been added to the heap since mark */
+	dmalloc_log_changed(_dm_mark, 1, 0, 1);
+	dmalloc_log_stats ();
+     }
+     _dm_mark = dmalloc_mark() ;
+     _dm_initialized = 1;
+#endif
+
     struct payload_digest *const sa_pd = md->chain[ISAKMP_NEXT_SA];
     struct state *st;
     struct connection *c;
@@ -678,6 +694,11 @@ main_inI1_outR1(struct msg_digest *md)
     /* Determin how many Vendor ID payloads we will be sending */
     int next;
     int numvidtosend = 1;  /* we always send DPD VID */
+
+#ifdef LEAK_DETECTIVE
+	report_leaks();         /* report memory leaks now, after all free()s */
+#endif
+
 #ifdef NAT_TRAVERSAL
     if (md->quirks.nat_traversal_vid && nat_traversal_enabled) {
 	DBG(DBG_NATT, DBG_log("nat-t detected, sending nat-t VID"));
@@ -1238,6 +1259,9 @@ main_inI2_outR2_calcdone(struct pluto_crypto_req_cont *pcrc
 
     st->hidden_variables.st_skeyid_calculated = TRUE;
     update_iv(st);
+    /* XXX: Do we need to free dh here? If so, how about the other exits?
+     * pfree(dh); dh = NULL;
+     */
 
     /*
      * if there was a packet received while we were calculating, then
@@ -1384,6 +1408,11 @@ main_inI2_outR2_tail(struct pluto_crypto_req_cont *pcrc
      *
      */
     {
+    /* Looks like we missed perform_dh() declared at
+     * programs/pluto/pluto_crypt.h as external and implemented nowhere.
+     * Following code regarding dh_continuation allocation seems useless
+     * as it's never used. At least, we should free it.
+     */
 	struct dh_continuation *dh = alloc_thing(struct dh_continuation
 						 , "main_inI2_outR2_tail");
 	stf_status e;
