@@ -26,7 +26,10 @@
 #include <openswan.h>
 #include <openswan/ipsec_policy.h>
 
+#include "sysdep.h"
 #include "constants.h"
+#include "oswtime.h"
+
 #include "defs.h"
 #include "id.h"
 #include "log.h"
@@ -505,7 +508,8 @@ check_ocsp(void)
 		    }
 		    datatot(certinfo->serialNumber.ptr, certinfo->serialNumber.len
 			, ':', buf, BUF_LEN);
-		    DBG_log("serial: %s, %ld seconds left", buf, time_left)
+		    DBG_log("serial: %s, %ld seconds left", buf
+			    , (unsigned long)time_left)
 		)
 
 #ifdef HAVE_THREADS
@@ -631,7 +635,7 @@ list_ocsp_locations(ocsp_location_t *location, bool requests, bool utc
 
 	if (certinfo != NULL)
 	{
-	    u_char buf[BUF_LEN];
+	    char buf[BUF_LEN];
 
 	    if (first)
 	    {
@@ -1193,7 +1197,7 @@ valid_ocsp_response(response_t *res)
 
     for (pathlen = 0; pathlen < MAX_CA_PATH_LEN; pathlen++)
     {
-	u_char buf[BUF_LEN];
+	char buf[BUF_LEN];
 	err_t ugh = NULL;
 	time_t until;
 
@@ -1272,11 +1276,11 @@ static bool
 parse_basic_ocsp_response(chunk_t blob, int level0, response_t *res)
 {
     u_int level, version, extn_oid = 0;
-    u_char buf[BUF_LEN];
+    char buf[BUF_LEN];
     asn1_ctx_t ctx;
     bool critical;
     chunk_t object;
-    int objectID = 0;
+    u_int objectID = 0;
 
     asn1_init(&ctx, blob, level0, FALSE, DBG_RAW);
 
@@ -1335,13 +1339,13 @@ parse_basic_ocsp_response(chunk_t blob, int level0, response_t *res)
 	    break;
 	case BASIC_RESPONSE_CERTIFICATE:
 	    {
-		chunk_t blob;
+		chunk_t blob2;
 		x509cert_t *cert = alloc_thing(x509cert_t, "ocspcert");
 
-		clonetochunk(blob, object.ptr, object.len, "ocspcert blob");
+		clonetochunk(blob2, object.ptr, object.len, "ocspcert blob");
 		*cert = empty_x509cert;
 
-                if (parse_x509cert(blob, level+1, cert)
+                if (parse_x509cert(blob2, level+1, cert)
                     && cert->isOcspSigner
                     && trust_authcert_candidate(cert, NULL))
 		{
@@ -1372,7 +1376,7 @@ parse_ocsp_response(chunk_t blob, response_t * res)
     asn1_ctx_t ctx;
     chunk_t object;
     u_int level;
-    int objectID = 0;
+    u_int objectID = 0;
 
     response_status rStatus = STATUS_INTERNALERROR;
     u_int ocspResponseType = 0;
@@ -1439,7 +1443,7 @@ parse_ocsp_single_response(chunk_t blob, int level0, single_response_t *sres)
     asn1_ctx_t ctx;
     bool critical;
     chunk_t object;
-    int objectID = 0;
+    u_int objectID = 0;
 
     asn1_init(&ctx, blob, level0, FALSE, DBG_RAW);
 
@@ -1557,7 +1561,7 @@ add_certinfo(ocsp_location_t *loc, ocsp_certinfo_t *info, ocsp_location_t **chai
     ocsp_location_t *location;
     ocsp_certinfo_t *certinfo, **certinfop;
     char buf[BUF_LEN];
-    time_t now;
+    time_t tnow;
     int cmp = -1;
 
     location = get_ocsp_location(loc, *chain);
@@ -1597,14 +1601,14 @@ add_certinfo(ocsp_location_t *loc, ocsp_certinfo_t *info, ocsp_location_t **chai
 	    , (cmp == 0)? (request?"already exists":"updated"):"added")
     )
 
-    time(&now);
+    time(&tnow);
    
     if (request)
     {
 	certinfo->status = CERT_UNDEFINED;
 	
 	if (cmp != 0)
-	    certinfo->thisUpdate = now;
+	    certinfo->thisUpdate = tnow;
 
 	certinfo->nextUpdate = UNDEFINED_TIME;
     }
@@ -1613,12 +1617,12 @@ add_certinfo(ocsp_location_t *loc, ocsp_certinfo_t *info, ocsp_location_t **chai
 	certinfo->status = info->status;
 
 	certinfo->thisUpdate = (info->thisUpdate != UNDEFINED_TIME)?
-	    info->thisUpdate : now;
+	    info->thisUpdate : tnow;
 
 	certinfo->once = (info->nextUpdate == UNDEFINED_TIME);
 
 	certinfo->nextUpdate = (certinfo->once)?
-	    (now + OCSP_DEFAULT_VALID_TIME) : info->nextUpdate;
+	    (tnow + OCSP_DEFAULT_VALID_TIME) : info->nextUpdate;
     }
 }
 
@@ -1722,7 +1726,7 @@ parse_ocsp(ocsp_location_t *location, chunk_t blob)
 	u_int level;
 	asn1_ctx_t ctx;
 	chunk_t object;
-	int objectID = 0;
+	u_int objectID = 0;
 
 	asn1_init(&ctx, res.responses, 0, FALSE, DBG_RAW);
 
