@@ -315,7 +315,6 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	*toomuch = TRUE;
 
 	pfree(cn);
-	pfree(r);
 	return NULL;
     }
 
@@ -712,22 +711,26 @@ static void init_crypto_helper(struct pluto_crypto_worker *w, int n)
 	int fd;
 	int maxfd;
 	struct rlimit nf;
-	int i;
+	int i, arg_len = 0;
 
 	/* diddle with our proc title */
 	memset(global_argv[0], '\0', strlen(global_argv[0])+1);
-	sprintf(global_argv[0], "pluto helper %s #%3d   ", pluto_ifn_inst, n);
+	arg_len += strlen(global_argv[0]);
 	for(i = 1; i < global_argc; i++) {
 	    if(global_argv[i]) {
 		int l = strlen(global_argv[i]);
 		memset(global_argv[i], '\0', l);
+		arg_len += l;
 	    }
 	    global_argv[i]=NULL;
 	}
+	snprintf(global_argv[0], arg_len, "pluto helper %s #%3d "
+			, pluto_ifn_inst, n);
 
 	if(getenv("PLUTO_CRYPTO_HELPER_DEBUG")) {
-	    sprintf(global_argv[0], "pluto helper %s #%3d (waiting for GDB) "
-		    , pluto_ifn_inst, n);
+	    sprintf(global_argv[0], arg_len,
+	    	    "pluto helper %s #%3d (waiting for GDB) ",
+		    pluto_ifn_inst, n);
 	    sleep(60); /* for debugger to attach */
 	    sprintf(global_argv[0], "pluto helper %s #%3d                   "
 		    , pluto_ifn_inst, n);
