@@ -872,9 +872,6 @@ exit_pluto(int status)
     stop_adns();            /* Stop async DNS process (if running) */
     free_md_pool();         /* free the md pool */
     delete_lock();          /* delete any lock files */
-#ifdef LEAK_DETECTIVE
-    report_leaks();         /* report memory leaks now, after all free()s */
-#endif /* LEAK_DETECTIVE */
     close_log();            /* close the logfiles */
     exit(status);           /* exit, with our error code */
 }
