@@ -1142,7 +1142,7 @@ parse_isakmp_sa_body(
 	if (ugh == NULL)
 	{
 		if (!ike_alg_ok_final(ta.encrypt, ta.enckeylen, ta.prf_hash,
-			ta.group ? ta.group->group : -1, c->alg_info_ike)) {
+			ta.group ? ta.group->group : 65535, c->alg_info_ike)) {
 			ugh = "OAKLEY proposal refused";
 		}
 	}
