@@ -67,6 +67,10 @@
 #include "ocf_pk.h"
 #endif
 
+#ifdef HAVE_OCF_AND_OPENSSL
+#include "ocf_cryptodev.h"
+#endif
+
 /* chained lists of X.509 host/user and ca certificates and crls */
 
 static x509cert_t *x509certs   = NULL;
@@ -447,7 +451,13 @@ load_crls(void)
 		chunk_t blob = empty_chunk;
 		char *filename = filelist[n]->d_name;
 
-		if (load_coded_file(filename, NULL, TRUE, "crl", &blob, &pgp))
+		if (load_coded_file(filename, NULL, 
+#ifdef SINGLE_CONF_DIR
+			FALSE, /* too verbose in a shared dir */
+#else
+			TRUE,
+#endif
+				"crl", &blob, &pgp))
 		{
 		    chunk_t crl_uri;
                     crl_uri.len = 8 + strlen(oco->crls_dir) + strlen(filename);
